@@ -63,9 +63,9 @@ at the top-level directory.
  * Versions 4.x and earlier do not include a #define'd version numbers.
  */
 #define SUPERLU_DIST_MAJOR_VERSION     5
-#define SUPERLU_DIST_MINOR_VERSION     2
-#define SUPERLU_DIST_PATCH_VERSION     2
-#define SUPERLU_DIST_RELEASE_DATE      "October 24, 2017"
+#define SUPERLU_DIST_MINOR_VERSION     3
+#define SUPERLU_DIST_PATCH_VERSION     0
+#define SUPERLU_DIST_RELEASE_DATE      "January 28, 2018"
 
 #include "superlu_dist_config.h"
 /* Define my integer size int_t */
@@ -168,8 +168,8 @@ at the top-level directory.
 #define LkVAL    14
 #define LkkDIAG  15
     /* For triangular solves. */
-#define XK_H     2  /* The header preceeding each X block. */
-#define LSUM_H   2  /* The header preceeding each MOD block. */
+#define XK_H     2  /* The header preceding each X block. */
+#define LSUM_H   2  /* The header preceding each MOD block. */
 #define GSUM     20 
 #define Xk       21
 #define Yk       22
@@ -230,6 +230,18 @@ at the top-level directory.
 #define VT_TRACEOFF
 #endif
 
+/* Support Windows */
+#ifndef SUPERLU_DIST_EXPORT
+#if MSVC
+#ifdef SUPERLU_DIST_EXPORTS
+#define SUPERLU_DIST_EXPORT __declspec(dllexport)
+#else
+#define SUPERLU_DIST_EXPORT __declspec(dllimport)
+#endif /* SUPERLU_DIST_EXPORTS */
+#else
+#define SUPERLU_DIST_EXPORT
+#endif /* MSVC */
+#endif /* SUPERLU_DIST_EXPORT */
 
 /***********************************************************************
  * New data types
